@@ -35,11 +35,28 @@ class Puppet::Provider::Openstack::Credentials
     env = {}
     self.instance_variables.each do |var|
       name = var.to_s.sub(/^@/,'OS_').upcase
-      env.merge!(name => self.instance_variable_get(var))
+      value = self.instance_variable_get(var)
+      unless value.nil?
+        env.merge!(name => value)
+      end
     end
     env
   end
 
+  def scope_set?
+    @project_name
+  end
+
+  def scope
+    if @project_name
+      return 'project'
+    else
+      # When only service token is used, there is not way to determine
+      # the scope unless we inspect the token using keystone API call.
+      return nil
+    end
+  end
+
   def user_password_set?
     return true if @username && @password && @project_name && @auth_url
   end
@@ -48,7 +65,7 @@ class Puppet::Provider::Openstack::Credentials
     self.instance_variables.each do |var|
       if var.to_s != '@identity_api_version' &&
         self.instance_variable_defined?(var.to_s)
-        set(var.to_s.sub(/^@/,''), '')
+        set(var.to_s.sub(/^@/,''), nil)
       end
     end
   end
@@ -70,10 +87,13 @@ class Puppet::Provider::Openstack::CredentialsV3 < Puppet::Provider::Openstack::
     :project_domain_id,
     :project_domain_name,
     :project_id,
+    :system_scope,
     :trust_id,
     :user_domain_id,
     :user_domain_name,
-    :user_id
+    :user_id,
+    :cloud,
+    :client_config_file,
   ]
 
   KEYS.each { |var| attr_accessor var }
@@ -82,8 +102,30 @@ class Puppet::Provider::Openstack::CredentialsV3 < Puppet::Provider::Openstack::
     KEYS.include?(name.to_sym) || super
   end
 
+  def user_set?
+    @username || @user_id
+  end
+
+  def scope_set?
+    @system_scope || @domain_name || @domain_id || @project_name || @project_id
+  end
+
+  def scope
+    if @project_name || @project_id
+      return 'project'
+    elsif @domain_name || @domain_id
+      return 'domain'
+    elsif @system_scope
+      return 'system'
+    else
+      # When clouds.yaml is used, parameters are not directly passed to puppet
+      # so the scope can't be detected.
+      return nil
+    end
+  end
+
   def user_password_set?
-    return true if (@username || @user_id) && @password && (@project_name || @project_id) && @auth_url
+    return true if (user_set? && @password && scope_set? && @auth_url) || @cloud
   end
 
   def initialize
